import learnsprout

apikey_env_var = "LEARNSPROUT_APIKEY" # specifyies the API key
root_url_env_var = "LEARNSPROUT_ROOT_URL" # specifies the API root_url uri
default_root_url = "https://v1.api.learnsprout.com"
default_pagesize = 200 # default number of results to retrieve per API call
user_agent = 'learnsprout-client-py/%s' % learnsprout.__version__

test_apikey = 'fcb8534c-e4ee-4e02-8b22-9328db1dac18'
